/** 
 *   Test: cmd_tools
 *
 *   (c) Copyright 2007 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 *   29/03/2007: Created.
 **/

#define _GNU_SOURCE


#include <stdio.h>
#include <stdint.h>
#include <limits.h>
#include <unistd.h>
#include <stdlib.h>
#include <getopt.h>

#include "my_stdio.h"
#include "cmd_tools.h"


int com_test __P((char *));

COMMAND my_commands[] = {
  { "cd",       0, 0, com_chdir, "[path]", "Change working directory" },
  { "export",   0, 0, com_export, "name=value", 
    "Change or add an environment variable" },	
  { "help",     0, 0, com_help, "[cmd]", "Display this text" },
  { "?",        0, 1, com_help, "[cmd]", "Synonym for `help'" },
  { "quit",     0, 0, com_quit, "", "Quit ..." },
  { "q",        0, 1, com_quit, "", "Quit :-)" },
  { "test",     0, 1, com_test,"", "[!]" },
  { (char *)NULL, 0, 0, (rl_icpfunc_t *)NULL, (char *) NULL, (char *)NULL }
};




const char *help_text[] ={
#       ifdef VERBOSE_MODE
        "  -v\t\t - Verbose mode (incremental).",
#       endif
        "  -n [--interac] - Not interactive mode.",
        "  -r\t\t - Don't use \"read line\" history.",
	"  --link\t - Make symbolic links for each command.",
	"  --unlink\t - Remove symbolic links for commands.",
        "  -h\t\t - This help !!!.",
        ""
};


int help(void)
{
	int i=0;

        while((char) *help_text[i] != 0) fprintf(stderr,"%s\n",help_text[i++]);
        fprintf(stderr,"\n");

	return 0;
}


int main(int argc, char * const argv[])
{
	int op;
	struct option const longopts[] =
        {
                {"help", 0, 0, 'h'},
                {"verbose", 0, 0, 'v'}, 
                {"interac", 0, 0, 'n'},
		{"link", 0, 0, 201},
		{"unlink", 0, 0, 202},
                {0,  0,  0,  0}
        };
	SET_VERBOSE_FLAG(PERR);
	
	cmd_tools_set_command(my_commands);
	cmd_tools_set_prompt("test> ");
	cmd_tools_use_history("cmd");
	
	while  ((op = getopt_long(argc, argv, "hnrv",longopts, 0)) != EOF)
		switch( op ){
		case 'n':
			
                        break;
		case 'r':

                        break;
		case 'v':
			INCREMENT_VERBOSE_FLAG();
			break;
		case 'V':
                        //version(program_name);
                        exit(-1);
                        break;
		case 201:
			cmd_tools_link_commands_to(argv[0] /*program_name*/ );
			exit(0); /* ok */ 
		case 202:
			cmd_tools_un_link_commands();
			exit(0); /* ok */
		case 'h':
		default:
			printf("Use %s [-v (incr.)]\n", argv[0]);
			help();
			exit(-1);
			break;
		}
	cmd_tools_use_baner(1);
	
	return cmd_tools_main_loop(argc, argv);
}


int com_test(char *cmd)
{

	printf("Test command [%s]\n", cmd);

	return 0;
}
